/*
 *	include/asm-mips/mach-au1x00/ioremap.h
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public License
 *	as published by the Free Software Foundation; either version
 *	2 of the License, or (at your option) any later version.
 */
#ifndef __ASM_MACH_AU1X00_IOREMAP_H
#define __ASM_MACH_AU1X00_IOREMAP_H

#include <linux/types.h>

#ifdef CONFIG_64BIT_PHYS_ADDR
static inline phys_t __fixup_bigphys_addr(phys_t phys_addr, phys_t size)
{
        /* Don't fixup 36 bit addresses */
        if ((phys_addr >> 32) != 0) return phys_addr;

#ifdef CONFIG_PCI
	else {
		u32 start, end;

		start = (u32)Au1500_PCI_MEM_START;
		end = (u32)Au1500_PCI_MEM_END;
		/* check for pci memory window */
		if ((phys_addr >= start) && ((phys_addr + size) < end)) {
			return (phys_t)((phys_addr - start) + Au1500_PCI_MEM_START);
		}
	}
#endif
        /* All Au1x SOCs have a pcmcia controller */
        /* We setup our 32 bit pseudo addresses to be equal to the
         * 36 bit addr >> 4, to make it easier to check the address
         * and fix it.
         * The Au1x socket 0 phys attribute address is 0xF 4000 0000.
         * The pseudo address we use is 0xF400 0000. Any address over
         * 0xF400 0000 is a pcmcia pseudo address.
         */
        if ((phys_addr >= 0xF4000000) && (phys_addr < 0xFFFFFFFF)) {
                return (phys_t)(phys_addr << 4);
        }

        /* default nop */
        return phys_addr;
}
#else
static inline phys_t __fixup_bigphys_addr(phys_t phys_addr, phys_t size)
{
	return phys_addr;
}
#endif

/*
 * Allow physical addresses to be fixed up to help 36-bit peripherals.
 */
static inline phys_t fixup_bigphys_addr(phys_t phys_addr, phys_t size)
{
	return __fixup_bigphys_addr(phys_addr, size);
}

#endif /* __ASM_MACH_AU1X00_IOREMAP_H */
